<?php
/**
*
* help_faq [Ukrainian]
*
* @package language
* @version $Id: help_faq.php,v 1.42 2007/10/04 15:07:24 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$help = array(
	array(
		0 => '--',
		1 => 'Вхід на форум і реєстрація'
	),
	array(
		0 => 'Чому я не можу увійти?',
		1 => 'На це може бути декілька причин. Перш за все, переконайтесь, чи правильно ви вводите ваше ім\'я користувача та пароль. Якщо це так, тоді вам необхідно зв\'язатися з адміністратором для того, щоб переконатись, що вам не заборонено доступ до форуму. Також можливо, що адміністратор невірно сконфігурував форум, і необхідно повідомити його про це для виправлення помилки.'
	),
	array(
		0 => 'Навіщо мені взагалі потрібно реєструватися?',
		1 => 'Ви можете цього і не робити, все залежить від того, як вирішив адміністратор форуму, чи потрібно вам реєструватись для розміщення повідомлень, чи ні. Проте, реєстрація надає вам можливість користуватись додатковими функціями, які недоступні для анонімних користувачів, такими як аватари, приватні повідомлення, відсилання e-mail учасникам форуму, участь в групах і т.п. Процес реєстрації забирає небагато часу і ми вам радимо пройти його.'
	),
	array(
		0 => 'Чому мені постійно доводиться логуватись?',
		1 => 'Якщо ви не ставите галочку напроти пункту <em>Запам\'ятати мене з цього комп\'ютера</em> під час входу на форум, ви будете залоговані лише протягом встановленого часу. Це запобігає використанню вашого облікового запису кимось іншим. Щоб залишатись залогованим, поставте галочку напроти цього пункту під час входу на форум, але це не рекомендується робити, якщо ви заходите на форум з загальнодоступного комп\'ютера, наприклад в бібліотеці, інтернет-кафе, університеті і т.п. Якщо такий пункт відсутній, це означає, що адміністратор вимкнув цю функцію.'
	),
	array(
		0 => 'Як мені зробити, щоб моє ім\'я користувача не з\'являлось в списку онлайн користувачів?',
		1 => 'В Панелі керування, а саме в розділі “Налаштування форуму” знайдіть пункт <em>Приховати моє перебування на форумі</em>, якщо ви залишите помітку напроти <samp>Так</samp>, ви будете видимі лише адміністраторам, модераторам та собі. Ви будете вважатись прихованим користувачем.'
	),
	array(
		0 => 'Я забув свій пароль',
		1 => 'Не панікуйте! Хоча ваш пароль не може бути відновлено, вам легко може бути створено новий. Для цього перейдіть на сторінку логування та натисніть <em>Я забув свій пароль</em>, дотримуйтесь інструкцій і незабаром ви знову зможете увійти на форум.'
	),
	array(
		0 => 'Я зареєструвався, але не можу увійти на форум!',
		1 => 'Перш за все, перевірте, чи вірно ви вводите ваше ім\'я користувача та пароль. Якщо з ними усе гаразд, причин може бути дві. Якщо увімкнено функцію COPPA і ви натиснули на <em>Мені менше 13 років</em> під час реєстрації, то вам необхідно дотримуватись інструкцій, які ви отримали. Якщо ні, то можливо ваш обліковий запис потребує активації. На деяких форумах вимагається, щоб усі зареєстровані облікові записи були активовані самостійно користувачами або адміністратором до того, як користувач зможе увійти на форум. В процесі реєстрації вам повідомлялось про те, чи необхідна вам активація чи ні. Якщо вам було надіслано лист електронною поштою, дотримуйтесь інструкцій, якщо ви не отримали листа, переконайтесь що ви вказали правильну адресу e-mail. Основна причина, з якої використовується активація облікового запису - це зменшення можливостей для анонімних зловживань на форумі. Якщо ви переконані, що ви ввели правильну адресу e-mail, спробуйте зв\'язатись з адміністратором форуму.'
	),
	array(
		0 => 'Я колись зареєструвався, але тепер не можу увійти на форум?!',
		1 => 'Можливо адміністратор з якихось причин видалив або вимкнув ваш обліковий запис. На багатьох форумах для зменшення розміру бази даних періодично видаляються облікові записи користувачів, які протягом довгого часу не створювали повідомлень. Якщо так сталось, спробуйте повторно зареєструватись і прийняти участь у дискусіях.'
	),
	array(
		0 => 'Що таке COPPA?',
		1 => 'COPPA (Child Online Privacy and Protection Act) або Акт про захист та конфіденційність дітей в мережі інтернет від 1998 року - це закон США, який вимагає від веб-сайтів, які можуть потенційно збирати інформацію від неповнолітніх, віком менше 13 років, мати на це письмову згоду від їхніх батьків або підтвердження від їхніх опікунів, що вони дозволяють збір особистої інформації від неповнолітніх, віком менше 13 років. Якщо ви не впевнені, чи це може бути застосоване щодо вас, як до особи, яка намагається зареєструватись, чи до сайту, на якому ви намагаєтесь зареєструватись, зверніться за допомогою до юрисконсульта. Зауважте, що phpBB Group не може надавати консультацій з юридичних питань і не є об\'єктом юридичних відносин, окрім вказаних нижче.',
	),
	array(
		0 => 'Чому я не можу зареєструватись?',
		1 => 'Можливо адміністратор форуму заборонив доступ з вашої адреси IP або ім\'я користувача, яке ви намагаєтесь зареєструвати. Також він міг вимкнути реєстрацію нових користувачів. Зверніться за допомогою до адміністратора форуму.',
	),
	array(
		0 => 'Що робить “Видалити встановлені форумом файли cookie”?',
		1 => '“Видалити встановлені форумом файли cookie” видаляє усі файли cookie, створені програмним забезпеченням phpBB3, які дозволяють вам залишатись авторизованим і залогованим на форумі, а також виконувати інші функції, такі як відстежування прочитаних повідомлень, якщо вони увімкнені адміністратором.',
	),
	array(
		0 => '--',
		1 => 'Параметри та налаштування'
	),
	array(
		0 => 'Як мені змінити мої налаштування?',
		1 => 'Якщо ви - зареєстрований користувач, усі ваші налаштування зберігаються в базі даних форуму. Для того, щоб змінити їх, відвідайте вашу <em>Панель керування</em>, зазвичай це посилання ви можете знайти у верхній частині сторінки. Там ви зможете змінити усі ваші налаштування та параметри.'
	),
	array(
		0 => 'На форумі встановлено невірний час!',
		1 => 'Можливо час, який відображається на форумі, відповідає іншому часовому поясу, а не тому, в якому знаходитесь ви. В такому випадку, відвідайте вашу Панель керування та змініть налаштуваннях часовий пояс, щоб він відповідав вашому місцезнаходженню, наприклад, Київ, Варшава, Москва і т.д. Зауважте, що зміна часового поясу та багатьох інших налаштувань доступна лише зареєстрованим користувачам. Отже, якщо ви незареєстровані, то це непоганий привід для того, щоб це зробити, пробачте за каламбур.'
	),
	array(
		0 => 'Я змінив часовий пояс, але час все одно невірний!',
		1 => 'Якщо ви впевнені в тому, що ви правильно встановили часовий пояс та літній час, але час все одно невірний, значить годинник на сервері налаштовано невірно. Будь-ласка, повідомте про це адміністратора, щоб він вирішив цю проблему.'
	),
	array(
		0 => 'Моя мова відсутня в списку!',
		1 => 'Одне з двох, або адміністратор не встановив підтримку вашої мови на форумі, або ще ніхто не переклав phpBB на вашу мову. Спробуйте запитати адміністратора, чи може він встановити необхідний вам мовний пакет, а якщо його не існує, ви можете самі створити новий переклад. Більш детальну інформацію ви можете знайти на сайті phpBB Group (посилання внизу сторінки).'
	),
	array(
		0 => 'Як я можу розмістити зображення поряд з своїм іменем користувача?',
		1 => 'При перегляді повідомлень може відображатись два зображення поряд з іменем користувача. Залежно від стилю форуму, перше зображення може відноситись до вашого звання, зазвичай у вигляді зірочок, блоків чи крапок, які відображають скільки повідомлень ви написали або ваш статус на форумі. Друге зображення, як правило більше, відоме як аватар, унікальне для кожного користувача. Від адміністратора форуму залежить чи дозволені аватари, і які саме аватари можуть використовуватись. Якщо ви не можете використовувати аватари, значить так вирішив адміністратор, ви можете запитати його про причини цієї заборони.'
	),
	array(
		0 => 'Що таке моє звання і як мені його змінити?',
		1 => 'Звання, яке знаходиться під вашим іменем користувача, відображає кількість повідомлень, яку ви написали, або дозволяє ідентифікувати певних користувачів, таких, як модератори або адміністратори. Взагалі ви не можете безпосередньо змінювати жодне звання на форумі, оскільки вони встановлюються адміністратором. Будь-ласка, не засмічуйте форум непотрібними повідомленнями тільки для того, щоб підняти своє звання, за це модератори чи адміністратори можуть просто зменшити кількість написаних вами повідомлень.'
	),
	array(
		0 => 'Коли я натискаю на посилання “e-mail”, щоб написати листа користувачу, від мене вимагається залогуватись?',
		1 => 'Лише зареєстровані користувачі можуть надсилати e-mail через вбудовану в форум форму відправлення e-mail, і лише якщо адміністратор увімкнув цю функцію. Це зроблено для запобігання зловживанню поштовою системою анонімними користувачами.'
	),
	array(
		0 => '--',
		1 => 'Створення повідомлень'
	),
	array(
		0 => 'Як мені створити тему на форумі?',
		1 => 'Для того щоб створити нову тему в одному з форумів, натисніть відповідну кнопку у вікні форуму або теми. Вам, можливо, буде потрібно зареєструватись для того, щоб розмістити повідомлення. Доступні для вас дії перераховано внизу сторінок форуму або теми (<em>Ви можете створювати нові теми, Ви можете голосувати в опитуваннях і т.п.</em>).'
	),
	array(
		0 => 'Як мені відредагувати або видалити повідомлення?',
		1 => 'Якщо ви не є адміністратором або модератором форуму, ви можете редагувати і видаляти лише власні повідомлення. Ви можете відредагувати повідомлення, натиснувши кнопку <em>редагувати</em> для відповідного повідомлення, інколи лише протягом обмеженого часу з моменту створення. Якщо вже хтось відповів на це повідомлення, то під ним з\'явиться невеличкий напис, який показує скільки разів ви редагували це повідомлення і коли це відбулось востаннє. Цей напис з\'явиться, якщо хтось відповів на це повідомлення; воно не з\'явиться, якщо модератор або адміністратор редагували його, хоча, у такому випадку, вони можуть залишити інформацію про причину редагування повідомлення та зроблені зміни. Майте на увазі, що звичайні користувачі не можуть видалити повідомлення, на яке вже хтось відповів.'
	),
	array(
		0 => 'Як мені додати підпис до мого повідомлення?',
		1 => 'Для того, щоб додати підпис до вашого повідомлення, вам необхідно спочатку створити його в вашому профілі. Після цього, ви можете поставити галочку напроти пункту <em>Приєднати підпис</em> в формі написання повідомлення для того, щоб підпис приєднався. Також ви можете встановити приєднання підпису за замовчуванням до усіх ваших повідомлень, поставивши відповідну відмітку в вашому профілі (ви зможете не приєднувати підпис до окремих повідомлень, знявши відмітку напроти пункту <em>Приєднати підпис</em> в формі написання повідомлення).'
	),
	array(
		0 => 'Як мені створити опитування?',
		1 => 'При створенні нової теми чи під час редагування першого повідомлення теми, натисніть <em>Створити опитування</em> під основною формою написання повідомлення; якщо ви не бачите її, то швидше за все, у вас недостатньо прав для створення опитувань. Введіть питання для опитування та, як мінімум, два варіанти відповіді в відповідних полях, кожен варіант потрібно вводити в окремій стрічці поля вводу тексту. Крім того, ви встановити кількість варіантів відповіді, які може обирати користувачі при голосуванні за допомогою “Options per user”, обмеження в часі для голосування в днях (0 для вічного голосування) і, накінець, можливість зміни своїх голосів користувачами.'
	),
	array(
		0 => 'Чому я не можу додати більше варіантів відповідей для свого опитування?',
		1 => 'Обмеження варіантів відповідей встановлює адміністратор форуму. Якщо у вас виникла необхідність створення більшої кількості варіантів для вашого опитування, аніж це передбачено, зв\'яжіться з адміністратором форуму.'
	),
	array(
		0 => 'Як мені змінити або видалити опитування?',
		1 => 'Так само як і повідомлення, опитування можуть редагуватись лише їхнім автором, модераторами або адміністраторами форуму. Для редагування опитування перейдіть до редагування першого повідомлення в темі (опитування завжди пов\'язане з ним). Якщо ніхто не проголосував ви можете видалити опитування або відредагувати будь-який з варіантів відповіді, але якщо вже хтось проголосував, лише модератори та адміністратори можуть редагувати та видаляти опитування. Це зроблено для того, щоб ніхто не зміг змінювати варіанти відповіді під час голосування'
	),
	array(
		0 => 'Чому мені недоступні деякі форуми?',
		1 => 'Деякі форуми можуть бути доступними лише певним учасникам та групам. Для перегляду, написання повідомлень і т.п. вам можливо потрібна додаткова авторизація, виключно модератори та адміністратори форуму можуть надати вам відповідний доступ, вам необхідно зв\'язатись з ними.'
	),
	array(
		0 => 'Чому я не можу приєднувати файли?',
		1 => 'Права на приєднання файлів встановлюються на рівні форумів, груп користувачів або окремих користувачів. Адміністратор форуму можливо заборонив приєднання файлів в форумі, в якому ви намагаєтесь написати, або можливо лише певні групи користувачів можуть приєднувати файли. Зв\'яжіться з адміністратором форуму, якщо ви не знаєте, чому ви не можете приєднувати файли.'
	),
	array(
		0 => 'Чому я отримав попередження?',
		1 => 'Кожен адміністратор форуму встановлює свої власні правила для свого сайту. Якщо що ви порушили правила, ви можете отримати попередження. Будь-ласка, майте на увазі, що це рішення адміністратора форуму, і phpBB Group немає жодного відношення до попередження, яке вам зробили на даному сайті.'
	),
	array(
		0 => 'Як мені поскаржитись на повідомлення модератору?',
		1 => 'Якщо адміністратор форуму увімкнув цю функцію, перейдіть до повідомлення, на яке ви хочете поскаржитись і ви побачите кнопку, якою ви можете це зробити. Натиснувши на неї, ви пройдете через ряд кроків, необхідних для відправлення скарги на повідомлення.'
	),
	array(
		0 => 'Що означає кнопка “Зберегти” в формі написання повідомлення?',
		1 => 'Вона дозволяє вам зберігати повідомлення для того, щоб завершити та розмістити їх пізніше. Для того, щоб завантажити їх, перейдіть в Панель керування у розділ Чернетки.'
	),
	array(
		0 => 'Чому моє повідомлення потребує схвалення?',
		1 => 'Адміністратор форуму можливо вирішив, що форум в який ви пишете, потребує спочатку перегляду повідомлень перед їхнім розміщенням. Також можливо, що адміністратор додав вас до групи користувачів, повідомлення яких потребують перегляду адміністратором перед їхнім розміщенням. Будь-ласка, зверніться до адміністратора для отримання більш детальної інформації.'
	),
	array(
		0 => 'Як мені знову підняти мою тему?',
		1 => 'Натиснувши на посилання “Підняти тему” при її перегляді, ви “піднімете” тему в верхню частину першої сторінки форуму. Якщо ви не бачите цього посилання, значить цю функцію вимкнено. Також можна підняти тему, просто відповівши на неї. При цьому переконайтесь, що ви не порушуєте правила форуму, в якому знаходитесь.'
	),
	array(
		0 => '--',
		1 => 'Форматування повідомлень та типи створюваних тем'
	),
	array(
		0 => 'Що таке BBCode?',
		1 => 'BBCode - це особлива реалізація HTML, можливість його використання визначається адміністратором (також ви можете вимкнути його в кожній формі написання повідомлення). BBCode схожий по стилю на HTML, але його теги беруться в квадратні дужки [ і ], а не в &lt; і &gt. Він надає більш широкі можливості виведення інформації на екран. Для отримання більш детальної інформації про BBCode перегляньте інструкцію з його використання, яка доступна з сторінки написання повідомлення.'
	),
	array(
		0 => 'Чи можу я використовувати HTML?',
		1 => 'Ні. На цьому форумі неможливе написання та обробка повідомлень за допомогою коду HTML. Більшість можливостей HTML для форматування тексту може бути реалізована за допомогою використання BBCode.'
	),
	array(
		0 => 'Що таке смайлики?',
		1 => 'Смайлики - це маленькі зображення, які можуть бути використані для передачі емоцій за допомогою короткого коду, наприклад, :) означає радість, :( означає сум. Весь список смайликів можна побачити в формі написання повідомлення. Намагайтесь не зловживати використанням смайликів, вони можуть швидко зробити ваше повідомлення нечитабельним і модератор може вирішити відредагувати його або просто видалити. Адміністратор форуму може обмежувати кількість смайликів, яке ви можете використати в одному повідомленні.'
	),
	array(
		0 => 'Чи можу я розміщувати зображення?',
		1 => 'Так, ви можете розміщувати зображення в своїх повідомленнях. Якщо адміністратор дозволив приєднання файлів, ви зможете завантажити зображення на форум. Якщо ні, ви повинні розмістити посилання на зображення, яке зберігається на загальнодоступному веб-сайті, наприклад: http://www.example.com/my-picture.gif. Ви не можете розміщувати посилання ні на зображення, які знаходяться на вашому власному комп\'ютері (за винятком, якщо він не є загальнодоступним сервером), ні на зображення, для доступу до яких потрібна автентифікація, наприклад, такі як поштові скриньки hotmail або yahoo, захищені паролем сайти і т.п.. Для відображення зображення в повідомленні, скористайтесь тегом BBCode [img].'
	),
	array(
		0 => 'Що таке “Важливо”?',
		1 => 'Важливі оголошення містять важливу інформацію і вам необхідно прочитати їх якнайшвидше. Вони відображаються в верхній частині форуму та в вашій Панелі керування. Можливість написання вами важливих оголошень залежить від прав доступу, встановлених адміністратором.'
	),
	array(
		0 => 'Що таке “Оголошення”?',
		1 => 'Оголошення найчастіше містять важливу інформацію для форуму, який ви переглядаєте в даний момент, і вам необхідно прочитати їх якнайшвидше. Оголошення відображаються в верхній частині кожної сторінки форуму, в якому вони розміщені. Так само як і з важливими оголошеннями, можливість написання вами оголошень залежить від прав доступу, встановлених адміністратором'
	),
	array(
		0 => 'Що таке “Прикріплено”?',
		1 => 'Прикріплені теми розміщуються під оголошеннями в форумі і виключно на першій сторінці. Вони, як правило, містять достатньо важливу інформаціюі при можливості вам необхідно прочитати їх. Так само як і з оголошеннями, можливість створення вами прикріплених тем залежить від прав доступу, встановлених адміністратором.'
	),
	array(
		0 => 'Що таке закриті теми?',
		1 => 'Теми можуть бути закриті виключно модераторами або адміністраторами форуму. Ви не можете відповідати в закриті теми і будь-які опитування в них автоматично завершуються. Теми можуть закриватись з різних причин.'
	),
	array(
		0 => 'Що таке значок теми?',
		1 => 'Значки тем - це встановлені автором зображення, які пов\'язані з повідомленнями та відображають їхній зміст. Можливість використання значків тем залежить від прав доступу, встановлених адміністратором.'
	),
  	// This block will switch the FAQ-Questions to the second template column
  	array(
  		0 => '--',
  		1 => '--'
  	),

	array(
		0 => '--',
		1 => 'Рівні користувачів та групи'
	),
	array(
		0 => 'Хто такі Адміністратори?',
		1 => 'Адміністратори - особи, які мають найвищий рівень контролю над форумом. Вони можуть керувати усіма аспектами роботи форуму, які включають розмежування прав доступу, закриття доступу окремим користувачам, створення груп, призначення модераторів і т.п., в залежності від прав, наданих їм засновником форуму. Також вони володіють усіма можливостями модераторів в усіх форумах, залежно від прав, наданих ним засновником форуму.'
	),
	array(
		0 => 'Хто такі Модератори?',
		1 => 'Модератори - це користувачі (або групи користувачів), чия робота полягає у щоденному стеженні за роботою форуму. Вони мають можливості редагування та видалення повідомлень, закриття, відкриття, переміщення, видалення та об\'єднання тем в форумі, який вони модерують. Основне завдання модераторів - не допускати відхилень від тем (<em>офтопіків</em>) та розміщень образливих та неприємних матеріалів.'
	),
	array(
		0 => 'Що таке групи користувачів?',
		1 => 'Групи ділять спільноту учасників на підрозділи, якими керують адміністратори форуму. Кожен учасник може належати до декількох груп і кожній групі може бути надано індивідуальні права доступу. Це полегшує адміністраторам призначити кількох користувачів модераторами форуму або надати їм доступ до приватних форумів і т.п.'
	),
	array(
		0 => 'Де знаходяться групи користувачів і як мені вступити до одної з груп?',
		1 => 'Ви можете переглянути усі групи користувачів за допомогою розділу Групи в вашій Панелі керування. Якщо ви бажаєте вступити в одну з них, натисніть на відповідне посилання. Звісно, не усі групи є загальнодоступними, деякі з них потребують схвалення для вступу, деякі можуть бути закритими або навіть прихованими. Якщо група є відкритою, ви можете вступити до неї натиснувши відповідну кнопку. Якщо група потребує схвалення вступу, ви можете відправити запит на вступ до неї, натиснувши відповідну кнопку. Лідер групи повинен схвалити ваш запит, він може запитати, чому ви бажаєте приєднатись до групи. Будь-ласка, не діставайте лідера групи питаннями, чому він відхилив ваш запит на вступ, він може мати на це свої причини.'
	),
	array(
		0 => 'Як мені стати Лідером групи?',
		1 => 'Коли групи створюються адміністратором форуму, він призначає лідера групи. Якщо ви зацікавлені у створенні групи, для початку зв\'яжіться з адміністратором форуму, відправивши йому приватне повідомлення.'
	),
	array(
		0 => 'Чому групи відображаються різними кольорами?',
		1 => 'Адміністратор форуму може встановлювати кольори учасникам груп для того, щоб їх легше було розрізняти.'
	),
	array(
		0 => 'Що таке “Група за замовчуванням”?',
		1 => 'Якщо ви є учасником більш ніж одної групи, ваша група за замовчуванням використовується для того, щоб визначити який колір та звання буде відображатись за замовчуванням. Адміністратор може надати вам право змінювати вашу групу за замовчуванням в вашій Панелі керування.'
	),
	array(
		0 => 'Що таке “Команда”?',
		1 => 'На цій сторінці ви знайдете список учасників, які здійснюють управління форумами, включаючи адміністраторів та модераторів та інформацію про те, які форуми вони модерують.'
	),
	array(
		0 => '--',
		1 => 'Приватні повідомлення'
	),
	array(
		0 => 'Я не можу відсилати приватні повідомлення!',
		1 => 'На це може бути три причини: 1) ви не зареєструвались і/або не залогувались; 2) адміністратор форуму вимкнув підтримку приватних повідомлень на форумі; 3) адміністратор заборонив вам відсилання приватних повідомлень. Якщо причина остання, то запитайте в адміністратора, чому він це зробив.'
	),
	array(
		0 => 'Я постійно отримую небажані приватні повідомлення!',
		1 => 'Ви можете заблокувати надходження вам приватних повідомлень від конкретного користувача, скориставшись правилами повідомлень в вашій Панелі керування. Якщо ви отримуєте образливі приватні повідомлення від одного з учасників, повідомте про це адміністратора форуму, він може заборонити йому можливість відправлення приватних повідомлень взагалі.'
	),
	array(
		0 => 'Я отримав спам або образливий лист email від учасника цього форуму!',
		1 => 'Нам прикро про це чути. Форма відправлення e-mail на цьому форумі включає засоби запобігання спробам відсилання таких листів і можливість відслідковування учасників, які відсилають повідомлення такого плану. Напишіть листа адміністратору форуму з повною копією листа e-mail, який ви отримали, при цьому важливо включити усі заголовки (вони містять детальну інформацію про учасника, який відправив лист). Адміністратор зреагує і зробить відповідні дії.'
	),
	array(
		0 => '--',
		1 => 'Друзі та недруги'
	),
	array(
		0 => 'Що таке список друзів та недругів?',
		1 => 'Ви можете використовувати ці списки для того, щоб впорядкувати інших учасників форуму. Учасники, додані до вашого списку друзів, будуть відображатись в вашій Панелі керування для швидкого доступу до інформації, чи вони зараз онлайн і для відсилання їм приватних повідомлень. Повідомлення від цих користувачів можуть виділятись, залежно від встановленого стилю (теми). Якщо ви додали учасника в список ваших недругів, усі його повідомлення буде приховано за замовчуванням.'
	),
	array(
		0 => 'Як я можу додавати / видаляти користувачів в мій список друзів або недругів?',
		1 => 'Ви можете додавати учасників в свої списки двома способами. В профілі кожного учасника є можливість додати його в ваш список друзів або недругів. Інший спосіб - додавати учасників, просто вводячи їхні імена користувача в вашій Панелі керування. В ній ви також можете видаляти учасників з ваших списків.'
	),
	array(
		0 => '--',
		1 => 'Пошук на форумі'
	),
	array(
		0 => 'Як мені здійснити пошук на форумі?',
		1 => 'Введіть умови пошуку в поле для пошуку, яке розміщене на головній сторінці форуму та на сторінках перегляду форумів та тем. Розширений пошук доступний за посиланням “Пошук”, яке знаходиться на кожній сторінці форуму. Розміщення посилань може відрізнятись, залежно від стилю, який використовується.'
	),
	array(
		0 => 'Чому мій пошук не дає результатів?',
		1 => 'Можливо ваш запит був надто суворо визначеним і включав багато загальних умов, які не індексуються phpBB3. Спробуйте задати ваш запит більш чітко та скористайтесь можливостями розширеного пошуку.'
	),
	array(
		0 => 'В результаті пошуку я отримав порожню сторінку!',
		1 => 'Ваш пошук дав надто велику кількість результатів, які не зміг обробити вебсервер. Використайте “Розширений пошук”, задайте форуми для пошуку та більш чітко сформулюйте ваш запит.'
	),
	array(
		0 => 'Як мені знайти учасників форуму?',
		1 => 'Перейдіть на сторінку “Учасники”, натисніть “Знайти учасника” та задайте необхідні критерії пошуку.'
	),
	array(
		0 => 'Як мені знайти власні повідомлення та теми?',
		1 => 'Ви можете знайти свої власні повідомлення, натиснувши “Знайти усі повідомлення учасника” в Панелі керування або на сторінці перегляду вашого профілю. Щоб знайти створені вами теми, скористайтесь розширеним пошуком і задайте необхідні для цього критерії.'
	),
	array(
		0 => '--',
		1 => 'Підписка на теми та закладки'
	),
	array(
		0 => 'У чому різниця між закладками та підпискою?',
		1 => 'Закладки в phpBB3 схожі на закладки в вашому веб-браузері. Вас не буде повідомлено про надходження нових повідомлень в тему, але ви зможете перейти в цю тему пізніше. Відмінність з підпискою полягає у тому, що якщо ви підпишитесь на тему, то вас буде повідомлено про надходження нових повідомлень в тему чи форум за допомогою встановленого вами способу чи способів.'
	),
	array(
		0 => 'Як мені підписатись на певні форуми чи теми?',
		1 => 'Для того, щоб підписатись на певний форум, натисніть на посилання “Підписатись на форум” перед тим, як до нього перейти. Для того, щоб підписатись на тему, поставте відповідну галочку при написанні відповіді, або натисніть на посилання “Підписатись на тему” в потрібній вам темі.'
	),
	array(
		0 => 'Як мені відмовитись від підписки?',
		1 => 'Для того, щоб відмовитись від підписки, перейдіть в вашу Панель керування у розділ Підписки.'
	),
	array(
		0 => '--',
		1 => 'Приєднання файлів'
	),
	array(
		0 => 'Які саме файли можна приєднувати на цьому форумі?',
		1 => 'Адміністратор кожного форуму сам визначає типи файлів, які дозволяється приєднувати. Якщо ви не впевнені, які файли дозволяєтеся приєднувати, а які ні, запитайте про це адміністратора цього форуму.'
	),
	array(
		0 => 'Як мені знайти усі приєднані мною файли?',
		1 => 'Для того, щоб побачити список усіх приєднаних вами файлів, перейдіть в Панель керування, і оберіть пункт Керування приєднаними файлами.'
	),
	array(
		0 => '--',
		1 => 'Інформація про phpBB 3'
	),
	array(
		0 => 'Хто створив цей форум?',
		1 => 'Це програмне забезпечення (в своїй незміненій формі) створене, випущене і поширюється <a href="http://www.phpbb.com/">phpBB Group</a>. Воно доступне за умовами ліцензії GNU General Public Licence і може вільно розповсюджуватись. Для отримання додаткової інформації перейдіть за посиланням.'
	),
	array(
		0 => 'Хто переклав цей форум на українську?',
		1 => 'Це програмне забезпечення перекладене і поширюється <a href="http://www.phpbb.com.ua/">Українською підтримкою phpBB</a>. Переклад також доступний за умовами ліцензії GNU General Public Licence і може вільно розповсюджуватись. Для отримання додаткової інформації перейдіть за посиланням.'
	),
	array(
		0 => 'Чому на форумі немає функції X?',
		1 => 'Це програмне забезпечення створено і ліцензовано phpBB Group. Якщо ви вважаєте, що необхідно додати якусь функцію, будь-ласка, відвідайте веб-сайт phpbb.com і перегляньте, яку думку відносно цього має phpBB Group. Будь-ласка, не розміщуйте запитів відносно нових функцій на форумі phpbb.com, phpBB Group використовує sourceforge для роботи над новими можливостями. Будь-ласка, спочатку перегляньте наші форуми, щоб дізнатись нашу думку на рахунок даної функції, і лише після цього дотримуйтесь процедури, яку вам буде надано.'
	),
	array(
		0 => 'З ким мені зв\'язатись з питань некоректного використання і/або юридичних питань, пов\'язаних з цим форумом?',
		1 => 'З приводу скарг звертайтесь до одного з адміністраторів форуму, вказаних на сторінці “Команда”. Якщо ви не отримаєте відповіді, зв\'яжіться з власником домену (зробіть <a href="http://www.google.com/search?q=whois">запит whois</a>), або, у випадку, якщо це безкоштовний сервіс (наприклад yahoo, free.fr, f2s.com і т.п.), з керівництвом або техпідтримкою цього сервісу. Зауважте, що phpBB Group немає <strong>абсолютно ніякої юрисдикції</strong> і не може в жоден спосіб нести будь-яку відповідальність за те, як, де і ким використовується даний форум. Не звертайтесь до phpBB Group з жодних юридичних питань (про припинення роботи форуму, відповідальності за нього, коментарів і т.і.), які не мають прямого відношення до вебсайту phpbb.com або програмного забезпечення phpBB. Якщо ви все-таки надішлете листа до phpBB Group з приводу використання цього програмного забезпечення <strong>третіми особами</strong>, не чекайте детальної відповіді чи будь-якої відповіді взагалі .'
	)
);

?>